summaryrefslogtreecommitdiffstats
path: root/gearman/controllerWorker/ControllerWorker/Boot.java
diff options
context:
space:
mode:
authorBjörn Geiger2011-08-10 13:05:09 +0200
committerBjörn Geiger2011-08-10 13:05:09 +0200
commit6b402874b466e66350a88266e1d477c680d98b1e (patch)
treed51eaa9ba372315d0cdf4023b8d7d29baeac6775 /gearman/controllerWorker/ControllerWorker/Boot.java
parentverschiedene Korrekturen (diff)
downloadpoolctrl-6b402874b466e66350a88266e1d477c680d98b1e.tar.gz
poolctrl-6b402874b466e66350a88266e1d477c680d98b1e.tar.xz
poolctrl-6b402874b466e66350a88266e1d477c680d98b1e.zip
verschiedenes
Diffstat (limited to 'gearman/controllerWorker/ControllerWorker/Boot.java')
-rw-r--r--gearman/controllerWorker/ControllerWorker/Boot.java30
1 files changed, 25 insertions, 5 deletions
diff --git a/gearman/controllerWorker/ControllerWorker/Boot.java b/gearman/controllerWorker/ControllerWorker/Boot.java
index 462508e..3fe6a05 100644
--- a/gearman/controllerWorker/ControllerWorker/Boot.java
+++ b/gearman/controllerWorker/ControllerWorker/Boot.java
@@ -202,12 +202,12 @@ public class Boot extends Thread {
wolJobs.remove(clientID);
} else {
System.out.println(ipAddress
- + " is not alive after WoL");
+ + " Cannot send magic packet.");
this.errors
.put(clientID,
"Sending the magic packet has been failed.");
- status.put(clientID, 18); // magic packet not send,
- // go in errorState
+ // cannot send magic packet, go in errorState
+ status.put(clientID, 18);
wolJobs.remove(clientID);
}
}
@@ -298,13 +298,21 @@ public class Boot extends Thread {
if (description.equals(this.bootOS)) {
System.out.println(ipAddress + " right OS");
- status.put(clientID, 19); // go in successState
+ status.put(clientID, 19); // right os
pingJobs.remove(clientID);
} else {
System.out.println(ipAddress + " wrong OS");
- status.put(clientID, 9); // check User
+ status.put(clientID, 9); // wrong os
pingJobs.remove(clientID);
}
+ } else {
+ System.out.println(ipAddress + " Cannot check os");
+ this.errors
+ .put(clientID,
+ "The check for correct operating system has been failed.");
+ // cannot check os, go in errorState
+ status.put(clientID, 18);
+ pingWoLJobs.remove(clientID);
}
}
}
@@ -349,6 +357,18 @@ public class Boot extends Thread {
status.put(clientID, 11); // wrong user
pingJobs.remove(clientID);
}
+ } else {
+ System.out.println(ipAddress
+ + " Cannot check if a user is logged in.");
+ this.errors
+ .put(clientID,
+ "The check if a user is logged in has been failed.");
+ /*
+ * cannot check if a user is logged in, go in
+ * errorState
+ */
+ status.put(clientID, 18);
+ pingWoLJobs.remove(clientID);
}
}
}